import Vue from 'vue'
import VueRouter from 'vue-router'

Vue.use(VueRouter)

const Layout = () => import('@/Layout/index.vue')

const routes = [
  {
    path: '/',
    redirect: '/login'
  },
  {
    path: '/login',
    name: 'login',
    component: () => import(/* webpackChunkName: "login" */ '@/views/login/login.vue'),
    meta: {
      transition: 'slide-left',
      title: '登录'
    }
  },
  {
    path: '/pwlogin',
    name: 'pwlogin',
    component: () => import(/* webpackChunkName: "register" */ '@/views/login/pwlogin.vue'),
    meta: {
      transition: 'slide-right',
      title: '登录'
    }
  },
  {
    path: '/forgotPW',
    name: 'forgotPW',
    component: () => import(/* webpackChunkName: "register" */ '@/views/login/forgotPW.vue'),
    meta: {
      transition: 'slide-right',
      title: '修改密码'
    }
  },
  {
    path: '/shopping-mall',
    name: 'shopping-mall',
    component: Layout,
    children: [
      {
        path: '/',
        component: () => import('@/views/shopping-mall/index.vue'),
        meta: {
          title: '分销系统'
        }
      }
    ]
  },
  {
    path: '/mine',
    name: 'mine',
    component: Layout,
    children: [
      {
        path: '/',
        component: () => import('@/views/mine/index.vue'),
        meta: {
          title: '个人中心'
        }
      }
    ]
  },
  {
    path: '/goods-detail/:id',
    name: 'goods-detail',
    component: () => import('@/views/goods-detail/index.vue'),
    meta: {
      title: '商品详情'
    }
  },
  {
    path: '/my-team',
    name: 'my-team',
    component: () => import('@/views/my-team/index.vue'),
    meta: {
      title: '团队成员'
    }
  },
  {
    path: '/addTeam',
    name: 'addTeam',
    component: () => import('@/views/my-team/addTeam.vue'),
    meta: {
      title: '添加成员'
    }
  },
  {
    path: '/order-report',
    name: 'order-report',
    component: () => import('@/views/order-report/index.vue'),
    meta: {
      title: '订单报备佣金'
    }
  },
  {
    path: '/order-report-detail',
    name: 'order-report-detail',
    component: () => import('@/views/order-report/detail.vue'),
    meta: {
      title: '订单报备佣金详情'
    }
  },
  {
    path: '/mine-card',
    name: 'mine-card',
    component: () => import('@/views/mine-card/index.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/mine-qrcode',
    name: 'mine-qrcode',
    component: () => import('@/views/mine-card/qrcode.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/save-card',
    name: 'save-card',
    component: () => import('@/views/mine-card/save-card.vue'),
    meta: {
      title: '我的名片'
    }
  },
  {
    path: '/account-settings',
    name: 'account-settings',
    component: () => import('@/views/login/account-settings.vue'),
    meta: {
      title: '账户设置'
    }
  },
  {
    path: '/order-sales',
    name: 'order-sales',
    component: () => import('@/views/order-sales/index.vue'),
    meta: {
      title: '订单销售佣金'
    }
  },
  {
    path: '/order-sales-detail',
    name: 'order-sales-detail',
    component: () => import('@/views/order-sales/detail.vue'),
    meta: {
      title: '订单销售佣金详情'
    }
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

export default router
